@@ -1,262 +1,270 @@
-package Regexp::Common; {
-
-use 5.00473;
+package Regexp::Common;
 use strict;
+use warnings;
+no warnings 'syntax';
 
-local $^W = 1;
+our $VERSION = 'v1.0.0'; # VERSION
+our %RE;
+our %sub_interface;
+our $AUTOLOAD;
 
-use vars qw /$VERSION %RE %sub_interface/;
+sub _croak {
+    require Carp;
+    goto &Carp::croak;
+}
 
-
-$VERSION = '0.09';
-
-use Carp;
+sub _carp {
+    require Carp;
+    goto &Carp::carp;
+}
 
 sub new {
-    my ($class, @data) = @_;
+    my ( $class, @data ) = @_;
     my %self;
     tie %self, $class, @data;
     return \%self;
 }
 
 sub TIEHASH {
-    my ($class, @data) = @_;
+    my ( $class, @data ) = @_;
     bless \@data, $class;
 }
 
 sub FETCH {
-    my ($self, $extra) = @_;
-    return bless ref($self)->new(@$self, $extra), ref($self);
+    my ( $self, $extra ) = @_;
+    return bless ref($self)->new( @$self, $extra ), ref($self);
 }
 
-my %imports = map {$_ => "Regexp::Common::$_"}
-              qw /balanced  comment delimited  list net number
-                  profanity URI     whitespace/;
+my %imports = map { $_ => "Regexp::Common::$_" }
+  qw /balanced CC     comment   delimited lingua list
+  net      number profanity SEN       URI    whitespace
+  zip/;
 
 sub import {
+    shift;    # Shift off the class.
     tie %RE, __PACKAGE__;
     {
         no strict 'refs';
-        *{caller() . "::RE"} = \%RE;
+        *{ caller() . "::RE" } = \%RE;
     }
 
-    my $saw_clean;
     my $saw_import;
     my $no_defaults;
     my %exclude;
-    foreach my $entry (grep {!/^RE_/} @_) {
-        if ($entry eq 'pattern') {
+    foreach my $entry ( grep { !/^RE_/ } @_ ) {
+        if ( $entry eq 'pattern' ) {
             no strict 'refs';
-            *{caller() . "::pattern"} = \&pattern;
+            *{ caller() . "::pattern" } = \&pattern;
             next;
         }
-        if ($entry eq 'clean') {
-            $saw_clean ++;
+
+        # This used to prevent $; from being set. We still recognize it,
+        # but we won't do anything.
+        if ( $entry eq 'clean' ) {
             next;
         }
-        if ($entry eq 'no_defaults') {
-            $no_defaults ++;
+        if ( $entry eq 'no_defaults' ) {
+            $no_defaults++;
             next;
         }
-        if (my $module = $imports {$entry}) {
-            $saw_import ++;
+        if ( my $module = $imports{$entry} ) {
+            $saw_import++;
             eval "require $module;";
             die $@ if $@;
             next;
         }
-        if ($entry =~ /^!(.*)/ && $imports {$1}) {
-            $exclude {$1} ++;
+        if ( $entry =~ /^!(.*)/ && $imports{$1} ) {
+            $exclude{$1}++;
             next;
         }
+
         # As a last resort, try to load the argument.
-        my $module = $entry =~ /^Regexp::Common/
-                            ? $entry
-                            : "Regexp::Common::" . $entry;
+        my $module =
+            $entry =~ /^Regexp::Common/
+          ? $entry
+          : "Regexp::Common::" . $entry;
         eval "require $module;";
         die $@ if $@;
     }
 
-    unless ($saw_import || $no_defaults) {
-        foreach my $module (values %imports) {
-            next if $exclude {$module};
+    unless ( $saw_import || $no_defaults ) {
+        foreach my $module ( values %imports ) {
+            next if $exclude{$module};
             eval "require $module;";
             die $@ if $@;
         }
     }
 
     my %exported;
-    foreach my $entry (grep {/^RE_/} @_) {
-        if ($entry =~ /^RE_(\w+_)?ALL$/) {
+    foreach my $entry ( grep { /^RE_/ } @_ ) {
+        if ( $entry =~ /^RE_(\w+_)?ALL$/ ) {
             my $m  = defined $1 ? $1 : "";
             my $re = qr /^RE_${m}.*$/;
-            while (my ($sub, $interface) = each %sub_interface) {
-                next if $exported {$sub};
+            while ( my ( $sub, $interface ) = each %sub_interface ) {
+                next if $exported{$sub};
                 next unless $sub =~ /$re/;
                 {
                     no strict 'refs';
-                    *{caller() . "::$sub"} = $interface;
+                    *{ caller() . "::$sub" } = $interface;
                 }
-                $exported {$sub} ++;
+                $exported{$sub}++;
             }
         }
         else {
-            next if $exported {$entry};
-            croak "Can't export unknown subroutine &$entry"
-                unless $sub_interface {$entry};
+            next if $exported{$entry};
+            _croak "Can't export unknown subroutine &$entry"
+              unless $sub_interface{$entry};
             {
                 no strict 'refs';
-                *{caller() . "::$entry"} = $sub_interface {$entry};
+                *{ caller() . "::$entry" } = $sub_interface{$entry};
             }
-            $exported {$entry} ++;
+            $exported{$entry}++;
         }
     }
-
-    $; = "=" unless $saw_clean;
 }
 
-use vars '$AUTOLOAD';
-sub AUTOLOAD { croak "Can't $AUTOLOAD" }
+sub AUTOLOAD { _croak "Can't $AUTOLOAD" }
 
-sub DESTROY {}
+sub DESTROY { }
 
 my %cache;
 
 my $fpat = qr/^(-\w+)/;
 
 sub _decache {
-        my @args = @{tied %{$_[0]}};
-        my @nonflags = grep {!/$fpat/} @args;
-        my $cache = get_cache(@nonflags);
-        croak "Can't create unknown regex: \$RE{"
-            . join("}{",@args) . "}"
-                unless exists $cache->{__VAL__};
-        croak "Perl $] does not support the pattern "
-            . "\$RE{" . join("}{",@args)
-            . "}.\nYou need Perl $cache->{__VAL__}{version} or later"
-                unless ($cache->{__VAL__}{version}||0) <= $];
-        my %flags = ( %{$cache->{__VAL__}{default}},
-                      map { /$fpat=(.*)/ ? ($1 => $2)
-                          : /$fpat/      ? ($1 => undef)
-                          :                ()
-                          } @args);
-        $cache->{__VAL__}->_clone_with(\@args, \%flags);
+    my @args     = @{ tied %{ $_[0] } };
+    my @nonflags = grep { !/$fpat/ } @args;
+    my $cache    = get_cache(@nonflags);
+    _croak "Can't create unknown regex: \$RE{" . join( "}{", @args ) . "}"
+      unless exists $cache->{__VAL__};
+    _croak "Perl $] does not support the pattern " . "\$RE{"
+      . join( "}{", @args )
+      . "}.\nYou need Perl $cache->{__VAL__}{version} or later"
+      unless ( $cache->{__VAL__}{version} || 0 ) <= $];
+    my %flags = (
+        %{ $cache->{__VAL__}{default} },
+        map {
+                /$fpat\Q$;\E(.*)/ ? ( $1 => $2 )
+              : /$fpat/           ? ( $1 => undef )
+              : ()
+        } @args
+    );
+    $cache->{__VAL__}->_clone_with( \@args, \%flags );
 }
 
 use overload q{""} => \&_decache;
 
-
 sub get_cache {
-        my $cache = \%cache;
-        foreach (@_) {
-                $cache = $cache->{$_}
-                      || ($cache->{$_} = {});
-        }
-        return $cache;
+    my $cache = \%cache;
+    foreach (@_) {
+        $cache = $cache->{$_}
+          || ( $cache->{$_} = {} );
+    }
+    return $cache;
 }
 
 sub croak_version {
-        my ($entry, @args) = @_;
+    my ( $entry, @args ) = @_;
 }
 
 sub pattern {
-        my %spec = @_;
-        croak 'pattern() requires argument: name => [ @list ]'
-                unless $spec{name} && ref $spec{name} eq 'ARRAY';
-        croak 'pattern() requires argument: create => $sub_ref_or_string'
-                unless $spec{create};
+    my %spec = @_;
+    _croak 'pattern() requires argument: name => [ @list ]'
+      unless $spec{name} && ref $spec{name} eq 'ARRAY';
+    _croak 'pattern() requires argument: create => $sub_ref_or_string'
+      unless $spec{create};
 
-        if (ref $spec{create} ne "CODE") {
-                my $fixed_str = "$spec{create}";
-                $spec{create} = sub { $fixed_str }
+    if ( ref $spec{create} ne "CODE" ) {
+        my $fixed_str = "$spec{create}";
+        $spec{create} = sub { $fixed_str }
+    }
+
+    my @nonflags;
+    my %default;
+    foreach ( @{ $spec{name} } ) {
+        if (/$fpat=(.*)/) {
+            $default{$1} = $2;
         }
-
-        my @nonflags;
-        my %default;
-        foreach ( @{$spec{name}} ) {
-                if (/$fpat=(.*)/) {
-                        $default{$1} = $2;
-                }
-                elsif (/$fpat\s*$/) {
-                        $default{$1} = undef;
-                }
-                else {
-                        push @nonflags, $_;
-                }
+        elsif (/$fpat\s*$/) {
+            $default{$1} = undef;
         }
-
-        my $entry = get_cache(@nonflags);
-
-        if ($entry->{__VAL__}) {
-                carp "Overriding \$RE{"
-                   . join("}{",@nonflags)
-                   . "}";
+        else {
+            push @nonflags, $_;
         }
+    }
 
-        $entry->{__VAL__} = bless {
-                                create  => $spec{create},
-                                match   => $spec{match} || \&generic_match,
-                                subs    => $spec{subs}  || \&generic_subs,
-                                version => $spec{version},
-                                default => \%default,
-                            }, 'Regexp::Common::Entry';
+    my $entry = get_cache(@nonflags);
 
-        foreach (@nonflags) {s/\W/X/g}
-        my $subname = "RE_" . join ("_", @nonflags);
-        $sub_interface{$subname} = sub {
-                push @_ => undef if @_ % 2;
-                my %flags = @_;
-                my $pat = $spec{create}->($entry->{__VAL__},
-                               {%default, %flags}, \@nonflags);
-                if (exists $flags{-keep}) { $pat =~ s/\Q(?k:/(/g; }
-                else { $pat =~ s/\Q(?k:/(?:/g; }
-                return qr/$pat/;
-        };
+    if ( $entry->{__VAL__} ) {
+        _carp "Overriding \$RE{" . join( "}{", @nonflags ) . "}";
+    }
 
-        return 1;
+    $entry->{__VAL__} = bless {
+        create  => $spec{create},
+        match   => $spec{match} || \&generic_match,
+        subs    => $spec{subs}  || \&generic_subs,
+        version => $spec{version},
+        default => \%default,
+      },
+      'Regexp::Common::Entry';
+
+    foreach (@nonflags) { s/\W/X/g }
+    my $subname = "RE_" . join( "_", @nonflags );
+    $sub_interface{$subname} = sub {
+        push @_ => undef if @_ % 2;
+        my %flags = @_;
+        my $pat   = $spec{create}
+          ->( $entry->{__VAL__}, { %default, %flags }, \@nonflags );
+        if   ( exists $flags{-keep} ) { $pat =~ s/\Q(?k:/(/g; }
+        else                          { $pat =~ s/\Q(?k:/(?:/g; }
+        return exists $flags{-i} ? qr /(?i:$pat)/ : qr/$pat/;
+    };
+
+    return 1;
 }
 
-sub generic_match { $_[0] =~ /$_[1]/ }
-sub generic_subs  { $_[0] =~ s/$_[1]/$_[2]/ }
+sub generic_match { $_[1] =~ /$_[0]/ }
+sub generic_subs  { $_[1] =~ s/$_[0]/$_[2]/ }
 
 sub matches {
-        my ($self, $str) = @_;
-        my $entry = $self->_decache;
-        $entry->{match}->($entry,$str);
+    my ( $self, $str ) = @_;
+    my $entry = $self->_decache;
+    $entry->{match}->( $entry, $str );
 }
 
 sub subs {
-        my ($self, $str, $newstr) = @_;
-        my $entry = $self->_decache;
-        $entry->{subs}->($entry, $str, $newstr);
-        return $str;
+    my ( $self, $str, $newstr ) = @_;
+    my $entry = $self->_decache;
+    $entry->{subs}->( $entry, $str, $newstr );
+    return $str;
 }
 
-}
+package Regexp::Common::Entry;
 
-package Regexp::Common::Entry; {
-use Carp;
-
-local $^W = 1;
+# use Carp;
 
 use overload
-    q{""} => sub {
-        my ($self) = @_;
-        my $pat = $self->{create}->($self, $self->{flags}, $self->{args});
-        if (exists $self->{flags}{-keep}) {
-            $pat =~ s/\Q(?k:/(/g;
-        }
-        else {
-            $pat =~ s/\Q(?k:/(?:/g;
-        }
-        return $pat;
-    };
+  q{""} => sub {
+    my ($self) = @_;
+    my $pat = $self->{create}->( $self, $self->{flags}, $self->{args} );
+    if ( exists $self->{flags}{-keep} ) {
+        $pat =~ s/\Q(?k:/(/g;
+    }
+    else {
+        $pat =~ s/\Q(?k:/(?:/g;
+    }
+    if ( exists $self->{flags}{-i} ) { $pat = "(?i)$pat" }
+    return $pat;
+  };
 
 sub _clone_with {
-    my ($self, $args, $flags) = @_;
-    bless { %$self, args=>$args, flags=>$flags }, ref $self;
+    my ( $self, $args, $flags ) = @_;
+    bless { %$self, args => $args, flags => $flags }, ref $self;
 }
 
-}
+1;
+
+__END__
 
 =pod
 
@@ -266,14 +274,14 @@ Regexp::Common - Provide commonly requested regular expressions
 
 =head1 SYNOPSIS
 
- # STANDARD USAGE 
+ # STANDARD USAGE
 
  use Regexp::Common;
 
  while (<>) {
      /$RE{num}{real}/               and print q{a number};
-     /$RE{quoted}                   and print q{a ['"`] quoted string};
-     /$RE{delimited}{-delim=>'/'}/  and print q{a /.../ sequence};
+     /$RE{quoted}/                  and print q{a ['"`] quoted string};
+    m[$RE{delimited}{-delim=>'/'}]  and print q{a /.../ sequence};
      /$RE{balanced}{-parens=>'()'}/ and print q{balanced parentheses};
      /$RE{profanity}/               and print q{a #*@%-ing word};
  }
@@ -294,7 +302,7 @@ Regexp::Common - Provide commonly requested regular expressions
 
  # IN-LINE MATCHING...
 
- if ( $RE{num}{int}->matches($text} ) {...}
+ if ( $RE{num}{int}->matches($text) ) {...}
 
 
  # ...AND SUBSTITUTION
@@ -318,7 +326,7 @@ Regexp::Common - Provide commonly requested regular expressions
                         my $char = quotemeta $flags->{-char};
                         return '(?:^$char+$)';
                     },
-         matches => sub {
+         match   => sub {
                         my ($self, $str) = @_;
                         return $str !~ /[^$self->{flags}{-char}]/;
                     },
@@ -350,37 +358,38 @@ L<"Subroutine-based interface">.
 
 To access a particular pattern, C<%RE> is treated as a hierarchical hash of
 hashes (of hashes...), with each successive key being an identifier. For
-example, to access the pattern that matches real numbers, you 
+example, to access the pattern that matches real numbers, you
 specify:
 
         $RE{num}{real}
-        
-and to access the pattern that matches integers: 
+
+and to access the pattern that matches integers:
 
         $RE{num}{int}
 
 Deeper layers of the hash are used to specify I<flags>: arguments that
 modify the resulting pattern in some way. The keys used to access these
-layers are prefixed with a minus sign and may include a value that is
-introduced by an equality sign. For example, to access the pattern that
+layers are prefixed with a minus sign and may have a value; if a value
+is given, it's done by using a multidimensional key.
+For example, to access the pattern that
 matches base-2 real numbers with embedded commas separating
 groups of three digits (e.g. 10,101,110.110101101):
 
-        $RE{num}{real}{'-base=2'}{'-sep=,'}{'-group=3'}
+        $RE{num}{real}{-base => 2}{-sep => ','}{-group => 3}
 
 Through the magic of Perl, these flag layers may be specified in any order
 (and even interspersed through the identifier keys!)
 so you could get the same pattern with:
 
-        $RE{num}{real}{'-sep=,'}{'-group=3'}{'-base=2'}
+        $RE{num}{real}{-sep => ','}{-group => 3}{-base => 2}
 
 or:
 
-        $RE{num}{'-base=2'}{real}{'-group=3'}{'-sep=,'}
+        $RE{num}{-base => 2}{real}{-group => 3}{-sep => ','}
 
 or even:
 
-        $RE{'-base=2'}{'-group=3'}{'-sep=,'}{num}{real}
+        $RE{-base => 2}{-group => 3}{-sep => ','}{num}{real}
 
 etc.
 
@@ -393,30 +402,20 @@ would not be the same as:
 
         $RE{set}{list}
 
+=head2 Flag syntax
 
-=head2 Alternative flag syntax
-
-As the examples in the previous section indicate, the syntax for
-specifying flags is somewhat cumbersome, because of the need to quote
-the entire (non-identifier) key-plus-value. To make such specifications
-less ugly, Regexp::Common permanently changes the value of the magical
-C<$;> variable (setting it to the character C<'='>), so that flags can
-also be specified like so:
-
-        $RE{num}{real}{-base=>2}{-group=>3}{-sep=>','}
-
-This syntax is preferred, and is used throughout the rest of this document.
-
-In the unlikely case that the non-standard value of C<$;> breaks your
-program, this behaviour can be disabled by importing the module as:
-
-        use Regexp::Common 'clean';
-
+In versions prior to 2.113, flags could also be written as
+C<{"-flag=value"}>. This no longer works, although C<{"-flag$;value"}>
+still does. However, C<< {-flag => 'value'} >> is the preferred syntax.
 
 =head2 Universal flags
 
 Normally, flags are specific to a single pattern.
-However, there is one flag that all patterns may specify.
+However, there is two flags that all patterns may specify.
+
+=over 4
+
+=item C<-keep>
 
 By default, the patterns provided by C<%RE> contain no capturing
 parentheses. However, if the C<-keep> flag is specified (it requires
@@ -437,6 +436,16 @@ substrings are saved.
 See also L<"Adding new regular expressions">, which describes how to create
 new patterns with "optional" capturing brackets that respond to C<-keep>.
 
+=item C<-i>
+
+Some patterns or subpatterns only match lowercase or uppercase letters.
+If one wants the do case insensitive matching, one option is to use
+the C</i> regexp modifier, or the special sequence C<(?i)>. But if the
+functional interface is used, one does not have this option. The
+C<-i> switch solves this problem; by using it, the pattern will do
+case insensitive matching.
+
+=back
 
 =head2 OO interface and inline matching/substitution
 
@@ -466,8 +475,8 @@ Regexp::Common allows you do write this:
 
         $changed = $RE{some}{pattern}->subs($original=>$replacement);
 
-Apart from reducing precedence-angst, this approach has the daded
-advantages that the substitution behaviour can be optimized from the 
+Apart from reducing precedence-angst, this approach has the added
+advantages that the substitution behaviour can be optimized from the
 regular expression, and the replacement string can be provided by
 default (see L<"Adding new regular expressions">).
 
@@ -494,7 +503,7 @@ effortlessly interpolated, and because it also allows them to be
 
         my $num = $RE{num}{int};
 
-        my $comma'd    = $num->{-sep=>','}{-group=>3};
+        my $commad     = $num->{-sep=>','}{-group=>3};
         my $duodecimal = $num->{-base=>12};
 
 
@@ -540,7 +549,7 @@ whose pattern names have first keys I<key1> ... I<keyn>.
 =head2 Adding new regular expressions
 
 You can add your own regular expressions to the C<%RE> hash at run-time,
-using the exportable C<pattern> subroutine. It expects a hash-like list of 
+using the exportable C<pattern> subroutine. It expects a hash-like list of
 key/value pairs that specify the behaviour of the pattern. The various
 possible argument pairs are:
 
@@ -558,7 +567,8 @@ flags it may take, via a reference to a list of strings. For example:
 This specifies an entry C<$RE{line}{of}>, which may take a C<-char> flag.
 
 Flags may also be specified with a default value, which is then used whenever
-the flag is omitted, or specified without an explicit value. For example:
+the flag is specified without an explicit value (but not when the flag is
+omitted). For example:
 
          pattern name => [qw( line of -char=_ )],
                  # default char is '_'
@@ -585,10 +595,10 @@ or a reference to a subroutine that will be called to create the pattern:
                             },
                 ;
 
-If the subroutine version is used, the subroutine will be called with 
+If the subroutine version is used, the subroutine will be called with
 three arguments: a reference to the pattern object itself, a reference
 to a hash containing the flags and their values,
-and a reference to an array containing the non-flag keys. 
+and a reference to an array containing the non-flag keys.
 
 Whatever the subroutine returns is stringified as the pattern.
 
@@ -602,7 +612,7 @@ It is a Regexp::Common convention that the outermost capturing parentheses
 always capture the entire pattern, but this is not enforced.
 
 
-=item C<matches =E<gt> $sub_ref>
+=item C<match =E<gt> $sub_ref>
 
 An optional argument that specifies a subroutine that is to be called when
 the C<$RE{...}-E<gt>matches(...)> method of this pattern is invoked.
@@ -614,7 +624,7 @@ It should return the same types of values as a C<m/.../> does.
 
      pattern name    => [qw( line of -char )],
              create  => sub {...},
-             matches => sub {
+             match   => sub {
                              my ($self, $str) = @_;
                              $str !~ /[^$self->{flags}{-char}]/;
                         },
@@ -661,7 +671,7 @@ However, it is possible to indicate which sets of patterns should
 be made available - the wanted sets should be given as arguments to
 C<use>. Alternatively, it is also possible to indicate which sets of
 patterns should not be made available - those sets will be given as
-argument to the C<use> statement, but are preceeded with an exclaimation
+argument to the C<use> statement, but are preceded with an exclaimation
 mark. The argument I<no_defaults> indicates none of the default patterns
 should be made available. This is useful for instance if all you want
 is the C<pattern()> subroutine.
@@ -679,7 +689,7 @@ you can have it made available with
  use Regexp::Common qw /my_patterns/;
 
 Note that the default patterns will still be made available - only if
-you use I<no_defaults>, or mention one of the default sets explicitely,
+you use I<no_defaults>, or mention one of the default sets explicitly,
 the non mentioned defaults aren't made available.
 
 =head2 List of available patterns
@@ -699,20 +709,24 @@ Provides regexes for strings with balanced parenthesized delimiters.
 
 =item Regexp::Common::comment
 
-Provides regexes for comments of various languages (26 languages
+Provides regexes for comments of various languages (43 languages
 currently).
 
 =item Regexp::Common::delimited
 
 Provides regexes for delimited strings.
 
+=item Regexp::Common::lingua
+
+Provides regexes for palindromes.
+
 =item Regexp::Common::list
 
 Provides regexes for lists.
 
 =item Regexp::Common::net
 
-Provides regexes for IPv4 addresses.
+Provides regexes for IPv4, IPv6, and MAC addresses.
 
 =item Regexp::Common::number
 
@@ -726,17 +740,21 @@ Provides regexes for profanity.
 
 Provides regexes for leading and trailing whitespace.
 
+=item Regexp::Common::zip
+
+Provides regexes for zip codes.
+
 =back
 
 =head2 Forthcoming patterns and features
 
 Future releases of the module will also provide patterns for the following:
 
-        * email addresses 
+        * email addresses
         * HTML/XML tags
         * more numerical matchers,
         * mail headers (including multiline ones),
-        * URLS (various genres)
+        * more URLS
         * telephone numbers of various countries
         * currency (universal 3 letter format, Latin-1, currency names)
         * dates
@@ -745,7 +763,7 @@ Future releases of the module will also provide patterns for the following:
 If you have other patterns or pattern generators that you think would be
 generally useful, please send them to the maintainer -- preferably as source
 code using the C<pattern> subroutine. Submissions that include a set of
-tests, will be especially welcome.
+tests will be especially welcome.
 
 
 =head1 DIAGNOSTICS
@@ -757,11 +775,11 @@ tests, will be especially welcome.
 The subroutine-based interface didn't recognize the requested subroutine.
 Often caused by a spelling mistake or an incompletely specified name.
 
-        
+
 =item C<Can't create unknown regex: $RE{...}>
 
 Regexp::Common doesn't have a generator for the requested pattern.
-Often indicates a mispelt or missing parameter.
+Often indicates a misspelt or missing parameter.
 
 =item
 C<Perl %f does not support the pattern $RE{...}.
@@ -798,104 +816,55 @@ You need to write: C<< $RE{delimited}{-delim=>I<X>'} >> for some character I<X>
 Deepest thanks to the many people who have encouraged and contributed to this
 project, especially: Elijah, Jarkko, Tom, Nat, Ed, and Vivek.
 
-=head1 HISTORY
+Further thanks go to: Alexandr Ciornii, Blair Zajac, Bob Stockdale,
+Charles Thomas, Chris Vertonghen, the CPAN Testers, David Hand,
+Fany, Geoffrey Leach, Hermann-Marcus Behrens, Jerome Quelin, Jim Cromie,
+Lars Wilke, Linda Julien, Mike Arms, Mike Castle, Mikko, Murat Uenalan,
+RafaE<235>l Garcia-Suarez, Ron Savage, Sam Vilain, Slaven Rezic, Smylers,
+Tim Maher, and all the others I've forgotten.
 
-  $Log: Common.pm,v $
-  Revision 1.19  2002/08/06 14:46:49  abigail
-  Upped version number to 0.09.
+=head1 NOT A BUG
 
-  Revision 1.18  2002/08/06 13:50:08  abigail
-  - Added HISTORY section with CVS log.
-  - Upped version number to 0.08.
+=over 4
 
-  Revision 1.17  2002/08/05 12:21:46  abigail
-  Upped version number to 0.07.
+=item *
 
-  Revision 1.16  2002/08/05 12:16:30  abigail
-  Fixed 'Regex::' typo to 'Regexp::' (Found my Mike Castle).
+The various patterns are not anchored. That is, a pattern like
+C<< $RE {num} {int} >> will match against "abc4def", because a
+substring of the subject matches. This is by design, and not a
+bug. If you want the pattern to be anchored, use something like:
 
-  Revision 1.15  2002/08/04 22:56:02  abigail
-  Upped version number to 0.06.
+ my $integer = $RE {num} {int};
+ $subj =~ /^$integer$/ and print "Matches!\n";
 
-  Revision 1.14  2002/08/04 19:33:33  abigail
-  Loaded URI by default.
-
-  Revision 1.13  2002/08/01 10:02:42  abigail
-  Upped version number.
-
-  Revision 1.12  2002/07/31 23:26:06  abigail
-  Upped version number.
-
-  Revision 1.11  2002/07/31 13:11:20  abigail
-  Removed URL from the list of default loaded regexes, as this one isn't
-  ready yet.
-
-  Upped the version number to 0.03.
-
-  Revision 1.10  2002/07/29 13:16:38  abigail
-  Introduced 'use strict' (which uncovered a bug, \@non_flags was used
-  when $spec{create} was called instead of \@nonflags).
-
-  Turned warnings on (using local $^W = 1; "use warnings" isn't available
-  in pre 5.6).
-
-  Revision 1.9  2002/07/28 23:02:54  abigail
-  Split out the remaining pattern groups to separate files.
-
-  Fixed a bug in _decache, changed the regex /$fpat=(.+)/ to
-  /$fpat=(.*)/, to be able to distinguish the case of a flag
-  set to the empty string, or a flag without an argument.
-
-  Added 'undef' to @_ in the sub_interface setting to avoid a warning
-  of setting a hash with an odd number of arguments.
-
-  POD fixes.
-
-  Revision 1.8  2002/07/25 23:55:54  abigail
-  Moved balanced, net and URL to separate files.
-
-  Revision 1.7  2002/07/25 20:01:40  abigail
-  Modified import() to deal with factoring out groups of related regexes.
-  Factored out comments into Common/comment.
-
-  Revision 1.6  2002/07/23 21:20:43  abigail
-  Upped version number to 0.02.
-
-  Revision 1.5  2002/07/23 21:14:55  abigail
-  Added $RE{comment}{HTML}.
-
-  Revision 1.4  2002/07/23 17:01:09  abigail
-  Added lines about new maintainer, and an email address to submit bugs
-  and new regexes to.
-
-  Revision 1.3  2002/07/23 13:58:58  abigail
-  Changed various occurences of C<... => ...> into C<< ... => ... >>.
-
-  Revision 1.2  2002/07/23 12:27:07  abigail
-  Line 733 was missing the closing > of a C<> in the POD.
-
-  Revision 1.1  2002/07/23 12:22:51  abigail
-  Initial revision
+=back
 
 =head1 AUTHOR
 
-Damian Conway (damian@conway.org)
+Alceu Rodrigues de Freitas Junior <glasswalk3r@yahoo.com.br>
 
-=head1 MAINTAINANCE
+=head1 LICENSE and COPYRIGHT
 
-This package is maintained by Abigail S<(I<regexp-common@abigail.nl>)>.
+This software is copyright (c) 2024 of Alceu Rodrigues de Freitas Junior,
+glasswalk3r at yahoo.com.br
 
-=head1 BUGS AND IRRITATIONS
+This file is part of regex-common project.
 
-Bound to be plenty.
+regex-commonis free software: you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation, either version 3 of the License, or (at your option) any later
+version.
 
-For a start, there are many common regexes missing.
-Send them in to I<regexp-common@abigail.nl>.
+regex-common is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+details.
 
+You should have received a copy of the GNU General Public License along with
+regex-common. If not, see (http://www.gnu.org/licenses/).
 
-=head1 COPYRIGHT
+The original project [Regexp::Common](https://metacpan.org/pod/Regexp::Common)
+is licensed through the MIT License, copyright (c) Damian Conway
+(damian@cs.monash.edu.au) and Abigail (regexp-common@abigail.be).
 
-         Copyright (c) 2001, Damian Conway. All Rights Reserved.
-       This module is free software. It may be used, redistributed
-      and/or modified under the terms of the Perl Artistic License
-            (see http://www.perl.com/perl/misc/Artistic.html)
+=cut
